@@ -1,18 +1,25 @@
 import os
 import asyncio
+import subprocess
+
 from packaging import version
 
 from pyshark.capture.capture import Capture
 from pyshark.tshark.tshark import get_tshark_interfaces, get_process_path
 
 
+class UnknownInterfaceException(Exception):
+    pass
+
+
 class LiveCapture(Capture):
     """Represents a live capture on a network interface."""
 
     def __init__(self, interface=None, bpf_filter=None, display_filter=None, only_summaries=False,
                  decryption_key=None, encryption_type='wpa-pwk', output_file=None, decode_as=None,
                  disable_protocol=None, tshark_path=None, override_prefs=None, capture_filter=None,
-                 monitor_mode=False, use_json=False, include_raw=False, eventloop=None, custom_parameters=None,
+                 monitor_mode=False, use_json=False, use_ek=False,
+                 include_raw=False, eventloop=None, custom_parameters=None,
                  debug=False):
         """Creates a new live capturer on a given interface. Does not start the actual capture itself.
 
@@ -31,22 +38,25 @@ class LiveCapture(Capture):
         :param override_prefs: A dictionary of tshark preferences to override, {PREFERENCE_NAME: PREFERENCE_VALUE, ...}.
         :param capture_filter: Capture (wireshark) filter to use.
         :param disable_protocol: Tells tshark to remove a dissector for a specifc protocol.
-        :param use_json: Uses tshark in JSON mode (EXPERIMENTAL). It is a good deal faster than XML
-        but also has less information. Available from Wireshark 2.2.0.
-        :param custom_parameters: A dict of custom parameters to pass to tshark, i.e. {"--param": "value"}
+        :param use_ek: Uses tshark in EK JSON mode. It is faster than XML but has slightly less data.
+        :param use_json: DEPRECATED. Use use_ek instead.
+        :param custom_parameters: A dict of custom parameters to pass to tshark, i.e. {"--param": "value"} or
+        else a list of parameters in the format ["--foo", "bar", "--baz", "foo"].
         """
         super(LiveCapture, self).__init__(display_filter=display_filter, only_summaries=only_summaries,
                                           decryption_key=decryption_key, encryption_type=encryption_type,
                                           output_file=output_file, decode_as=decode_as, disable_protocol=disable_protocol,
                                           tshark_path=tshark_path, override_prefs=override_prefs,
-                                          capture_filter=capture_filter, use_json=use_json, include_raw=include_raw,
+                                          capture_filter=capture_filter, use_json=use_json, use_ek=use_ek,
+                                          include_raw=include_raw,
                                           eventloop=eventloop, custom_parameters=custom_parameters,
                                           debug=debug)
         self.bpf_filter = bpf_filter
         self.monitor_mode = monitor_mode
 
+        self._all_interfaces = get_tshark_interfaces(tshark_path)
         if interface is None:
-            self.interfaces = get_tshark_interfaces(tshark_path)
+            self.interfaces = self._all_interfaces
         elif isinstance(interface, str):
             self.interfaces = [interface]
         else:
@@ -59,6 +69,12 @@ class LiveCapture(Capture):
         params += ["-i", "-"]
         return params
 
+    def _verify_capture_parameters(self):
+        for each_interface in self.interfaces:
+            if each_interface not in self._all_interfaces:
+                raise UnknownInterfaceException(
+                    f"Interface '{each_interface}' does not exist, unable to initiate capture.")
+
     def _get_dumpcap_parameters(self):
         # Don't report packet counts.
         params = ["-q"]
@@ -82,7 +98,8 @@ class LiveCapture(Capture):
 
         self._log.debug("Creating Dumpcap subprocess with parameters: %s" % " ".join(dumpcap_params))
         dumpcap_process = await asyncio.create_subprocess_exec(*dumpcap_params, stdout=write,
-                                                               stderr=self._stderr_output())
+                                                               stderr=subprocess.PIPE)
+        self._create_stderr_handling_task(dumpcap_process.stderr)
         self._created_new_process(dumpcap_params, dumpcap_process, process_name="Dumpcap")
 
         tshark = await super(LiveCapture, self)._get_tshark_process(packet_count=packet_count, stdin=read)
