@@ -1,4 +1,6 @@
 """Module used for the actual running of TShark"""
+import json
+
 from packaging import version
 import os
 import subprocess
@@ -26,12 +28,17 @@ def get_process_path(tshark_path=None, process_name="tshark"):
     :param tshark_path: Path of the tshark binary
     :raises TSharkNotFoundException in case TShark is not found in any location.
     """
+    possible_paths = []
+    # Check if `config.ini` exists in the current directory or the pyshark directory
     config = get_config()
-    possible_paths = [config.get(process_name, "%s_path" % process_name)]
+    if config:
+        possible_paths.append(config.get(process_name, "%s_path" % process_name))
 
     # Add the user provided path to the search list
     if tshark_path is not None:
-        possible_paths.insert(0, tshark_path)
+        user_tshark_path = os.path.join(os.path.dirname(tshark_path),
+                                        "%s.exe" % process_name if sys.platform.startswith("win") else process_name)
+        possible_paths.insert(0, user_tshark_path)
 
     # Windows search order: configuration file"s path, common paths.
     if sys.platform.startswith("win"):
@@ -49,6 +56,8 @@ def get_process_path(tshark_path=None, process_name="tshark"):
         )
         for path in os_path.split(":"):
             possible_paths.append(os.path.join(path, process_name))
+    if sys.platform.startswith("darwin"):
+        possible_paths.append(f"/Applications/Wireshark.app/Contents/MacOS/{process_name}")
 
     for path in possible_paths:
         if os.path.exists(path):
@@ -102,3 +111,37 @@ def get_tshark_interfaces(tshark_path=None):
         tshark_interfaces = subprocess.check_output(parameters, stderr=null).decode("utf-8")
 
     return [line.split(" ")[1] for line in tshark_interfaces.splitlines() if not '\\\\.\\' in line]
+
+
+def get_ek_field_mapping(tshark_path=None):
+    parameters = [get_process_path(tshark_path), "-G", "elastic-mapping"]
+    with open(os.devnull, "w") as null:
+        mapping = subprocess.check_output(parameters, stderr=null).decode("ascii")
+
+    mapping = json.loads(
+        mapping,
+        object_pairs_hook=_duplicate_object_hook)["mappings"]
+    if "doc" in mapping:
+        mapping = mapping["doc"]
+    elif "pcap_file" in mapping:
+        mapping = mapping["pcap_file"]
+    else:
+        raise TSharkVersionException(f"Your tshark version does not support elastic-mapping. Please upgrade.")
+
+    return mapping["properties"]["layers"]["properties"]
+
+
+def _duplicate_object_hook(ordered_pairs):
+    """Make lists out of duplicate keys."""
+    json_dict = {}
+    for key, val in ordered_pairs:
+        existing_val = json_dict.get(key)
+        if not existing_val:
+            json_dict[key] = val
+        else:
+            # There are duplicates without any data for some reason, if it's that - drop it
+            # Otherwise, override
+            if val.get("properties") != {}:
+                json_dict[key] = val
+
+    return json_dict
